==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/af/mail.php <==
<?php

return array(
    'a_user_canceled' => '\'N Gebruiker het \'n itemversoek op die webwerf gekanselleer',
    'a_user_requested' => '\'N Gebruiker het \'n item op die webwerf versoek',
    'accessory_name' => 'Toebehore Naam:',
    'additional_notes' => 'Bykomende aantekeninge:',
    'admin_has_created' => '\'N Administrateur het \'n rekening vir jou op die webtuiste gemaak.',
    'asset' => 'bate:',
    'asset_name' => 'Bate Naam:',
    'asset_requested' => 'Bate aangevra',
    'asset_tag' => 'Bate-tag:',
    'assigned_to' => 'Toevertrou aan',
    'best_regards' => 'Beste wense,',
    'canceled' => 'gekanselleer:',
    'checkin_date' => 'Incheckdatum:',
    'checkout_date' => 'Checkout Datum:',
    'click_to_confirm' => 'Klik asseblief op die volgende skakel om u webadres te bevestig:',
    'click_on_the_link_accessory' => 'Klik asseblief op die skakel onderaan om te bevestig dat u die bykomstigheid ontvang het.',
    'click_on_the_link_asset' => 'Klik asseblief op die skakel onderaan om te bevestig dat u die bate ontvang het.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'Huidige QTY',
    'Days' => 'dae',
    'days' => 'dae',
    'expecting_checkin_date' => 'Verwagte inskrywingsdatum:',
    'expires' => 'verstryk',
    'Expiring_Assets_Report' => 'Verlenging van bateverslag.',
    'Expiring_Licenses_Report' => 'Verlenging van lisensiesverslag.',
    'hello' => 'hallo',
    'hi' => 'Hi',
    'i_have_read' => 'Ek het die gebruiksvoorwaardes gelees en ingestem en het hierdie item ontvang.',
    'item' => 'item:',
    'Item_Request_Canceled' => 'Item Versoek gekanselleer',
    'Item_Requested' => 'Item gevra',
    'link_to_update_password' => 'Klik asseblief op die volgende skakel om u webtuiste te verander:',
    'login_first_admin' => 'Teken in op jou nuwe Snipe-IT-installasie deur die volgende inligting te gebruik:',
    'login' => 'Teken aan:',
    'Low_Inventory_Report' => 'Lae voorraadverslag',
    'min_QTY' => 'Min QTY',
    'name' => 'naam',
    'new_item_checked' => '\'N Nuwe item is onder u naam nagegaan, besonderhede is hieronder.',
    'password' => 'wagwoord:',
    'password_reset' => 'Wagwoord Herstel',

    'read_the_terms' => 'Lees asseblief die gebruiksvoorwaardes hieronder.',
    'read_the_terms_and_click' => 'Lees asseblief die gebruiksvoorwaardes hieronder en klik op die skakel onderaan om te bevestig dat u die gebruiksvoorwaardes lees en stem en die bate ontvang het.',
    'requested' => 'versoek:',
    'reset_link' => 'Jou wagwoord herstel skakel',
    'reset_password' => 'Klik hier om jou wagwoord terug te stel:',
    'serial' => 'Serial',
    'supplier' => 'verskaffer',
    'tag' => 'tag',
    'test_email' => 'Toets e-pos van Snipe-IT',
    'test_mail_text' => 'Dit is \'n toets van die Snipe-IT Batebestuurstelsel. As jy dit het, werk die pos :)',
    'the_following_item' => 'Die volgende item is nagegaan:',
    'low_inventory_alert' => 'There is :count item that is below minimum inventory or will soon be low.|There are :count items that are below minimum inventory or will soon be low.',
    'assets_warrantee_alert' => 'There is :count asset with a warrantee expiring in the next :threshold days.|There are :count assets with warrantees expiring in the next :threshold days.',
    'license_expiring_alert' => 'There is :count license expiring in the next :threshold days.|There are :count licenses expiring in the next :threshold days.',
    'to_reset' => 'Om jou webadres te herstel, voltooi hierdie vorm:',
    'type' => 'tipe',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'User',
    'username' => 'Username',
    'welcome' => 'Welkom: naam',
    'welcome_to' => 'Welkom by: web!',
    'your_credentials' => 'Jou Snipe-IT-referenties',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets'
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/af/mail.php <==
<?php

return [
    'a_user_canceled' => '\'N Gebruiker het \'n itemversoek op die webwerf gekanselleer',
    'a_user_requested' => '\'N Gebruiker het \'n item op die webwerf versoek',
    'accessory_name' => 'Toebehore Naam:',
    'additional_notes' => 'Bykomende aantekeninge:',
    'admin_has_created' => '\'N Administrateur het \'n rekening vir jou op die webtuiste gemaak.',
    'asset' => 'bate:',
    'asset_name' => 'Bate Naam:',
    'asset_requested' => 'Bate aangevra',
    'asset_tag' => 'Asset Tag',
    'assigned_to' => 'Toevertrou aan',
    'best_regards' => 'Beste wense,',
    'canceled' => 'gekanselleer:',
    'checkin_date' => 'Incheckdatum:',
    'checkout_date' => 'Checkout Datum:',
    'click_to_confirm' => 'Klik asseblief op die volgende skakel om u webadres te bevestig:',
    'click_on_the_link_accessory' => 'Klik asseblief op die skakel onderaan om te bevestig dat u die bykomstigheid ontvang het.',
    'click_on_the_link_asset' => 'Klik asseblief op die skakel onderaan om te bevestig dat u die bate ontvang het.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'Huidige QTY',
    'Days' => 'dae',
    'days' => 'dae',
    'expecting_checkin_date' => 'Verwagte inskrywingsdatum:',
    'expires' => 'verstryk',
    'Expiring_Assets_Report' => 'Verlenging van bateverslag.',
    'Expiring_Licenses_Report' => 'Verlenging van lisensiesverslag.',
    'hello' => 'hallo',
    'hi' => 'Hi',
    'i_have_read' => 'Ek het die gebruiksvoorwaardes gelees en ingestem en het hierdie item ontvang.',
    'item' => 'item:',
    'Item_Request_Canceled' => 'Item Versoek gekanselleer',
    'Item_Requested' => 'Item gevra',
    'link_to_update_password' => 'Klik asseblief op die volgende skakel om u webtuiste te verander:',
    'login_first_admin' => 'Teken in op jou nuwe Snipe-IT-installasie deur die volgende inligting te gebruik:',
    'login' => 'Teken aan:',
    'Low_Inventory_Report' => 'Lae voorraadverslag',
    'min_QTY' => 'Min QTY',
    'name' => 'naam',
    'new_item_checked' => '\'N Nuwe item is onder u naam nagegaan, besonderhede is hieronder.',
    'password' => 'wagwoord:',
    'password_reset' => 'Wagwoord Herstel',

    'read_the_terms' => 'Lees asseblief die gebruiksvoorwaardes hieronder.',
    'read_the_terms_and_click' => 'Lees asseblief die gebruiksvoorwaardes hieronder en klik op die skakel onderaan om te bevestig dat u die gebruiksvoorwaardes lees en stem en die bate ontvang het.',
    'requested' => 'versoek:',
    'reset_link' => 'Jou wagwoord herstel skakel',
    'reset_password' => 'Klik hier om jou wagwoord terug te stel:',
    'serial' => 'Serial',
    'supplier' => 'verskaffer',
    'tag' => 'tag',
    'test_email' => 'Toets e-pos van Snipe-IT',
    'test_mail_text' => 'Dit is \'n toets van die Snipe-IT Batebestuurstelsel. As jy dit het, werk die pos :)',
    'the_following_item' => 'Die volgende item is nagegaan:',
    'low_inventory_alert' => 'There is :count item that is below minimum inventory or will soon be low.|There are :count items that are below minimum inventory or will soon be low.',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'license_expiring_alert' => 'There is :count license expiring in the next :threshold days.|There are :count licenses expiring in the next :threshold days.',
    'to_reset' => 'Om jou webadres te herstel, voltooi hierdie vorm:',
    'type' => 'tipe',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'User',
    'username' => 'Username',
    'welcome' => 'Welkom: naam',
    'welcome_to' => 'Welkom by: web!',
    'your_credentials' => 'Jou Snipe-IT-referenties',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets',
];
